
#line 3 "lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 31
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L
#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 1;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 155
#define YY_END_OF_BUFFER 156
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[401] =
    {   0,
        0,    0,  156,  154,  132,   61,  133,  131,   99,  154,
      100,   51,   98,  101,  154,   62,   63,   90,   88,   50,
       89,   54,   92,  136,  149,  128,   49,  112,   87,  113,
      126,  153,   65,   66,  103,  153,  153,  153,  153,  153,
      153,  153,  153,  153,  153,  153,  153,  153,  153,  153,
      153,   67,  102,   68,  104,  153,  153,  153,  132,  131,
        2,  110,    0,  135,    0,   77,  118,   85,    0,  134,
        0,   96,   71,   64,  106,   69,  108,   70,   55,    0,
      152,    0,    1,   94,   73,  152,  136,  149,    0,    0,
        0,    0,  127,  122,  114,   59,  109,   57,  116,  124,

      153,   84,  153,  153,  153,  153,  153,  153,   10,  153,
      153,  153,  153,  153,  153,  153,  153,   11,  153,  153,
      153,  153,  153,  153,  153,  153,  153,  153,  153,  153,
      153,  153,  153,  153,  153,  153,   86,  120,  105,  129,
      130,   91,   93,  153,  153,  153,  153,  153,  153,  153,
      153,  153,    0,    2,  135,  134,   78,   52,    0,   75,
      151,  152,    0,    0,  152,    0,  141,    0,  137,    0,
      145,   80,   82,  153,  153,  153,  153,  153,  153,  153,
      153,  153,  153,  153,  153,  153,    9,  153,  153,  153,
       24,  153,  153,  153,  153,  153,  153,  153,  153,  153,

      153,  153,  153,  153,  153,   19,  153,  153,  153,  153,
      153,   72,   74,   53,   97,   56,   58,  119,  121,  111,
      115,  117,   60,  107,  123,  125,   95,  152,    0,    0,
      144,    0,  144,    0,  140,    0,  140,    0,  148,    0,
      148,  145,    3,   23,  153,   16,  153,  153,  153,  153,
       12,   34,  153,  153,  153,   28,  153,   41,   40,  153,
      153,  153,   22,  153,  153,  153,  153,   26,  153,  153,
      153,  153,  153,  153,  153,   37,  153,  153,  153,   35,
      153,   79,   81,   83,   76,  150,    0,  143,  144,    0,
        0,  144,    0,  139,  140,    0,    0,  140,  148,    0,

      147,  148,  148,    0,    0,  145,  145,   14,   20,    4,
      153,  153,  153,  153,   38,  153,  153,  153,  153,  153,
      153,  153,   45,  153,  153,  153,  153,  153,  153,  153,
      153,   21,  153,   33,    8,  144,    0,    0,  140,    0,
        0,  148,  148,  148,    0,  148,  148,    0,  148,  153,
      153,  153,   48,  153,  153,    5,   43,  153,  153,   47,
      153,   18,  153,    6,   27,   32,   13,   31,  153,  142,
      138,    0,  146,  153,   17,  153,   36,  153,  153,  153,
      153,  153,   39,  153,   15,  153,    7,  153,  153,   25,
      153,  153,   44,   42,   46,   29,  153,  153,   30,    0

    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
       23,   23,   23,   23,   23,   24,   24,   25,   26,   27,
       28,   29,   30,    1,   31,   31,   31,   31,   32,   31,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       34,   35,   36,   37,   33,    1,   38,   39,   40,   41,

       42,   43,   44,   45,   46,   33,   47,   48,   49,   50,
       51,   52,   33,   53,   54,   55,   56,   57,   58,   59,
       60,   33,   61,   62,   63,   64,    1,   65,   33,   33,
       33,   33,   33,   66,   67,   68,   69,   70,   33,   33,
       33,   33,   33,   33,   71,   72,   33,   33,   33,   33,
       73,   33,   33,   33,   33,   33,   33,   33,   33,   74,
       75,   76,   33,   77,   78,   79,   80,   81,   33,   82,
       83,   84,   33,   33,   33,   33,   33,   85,   86,   33,
       33,   33,   87,   33,   33,   88,   33,   33,   89,   33,
       33,   33,   33,   90,   91,   33,   33,   33,   33,   33,

       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   92,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33
    } ;

static yyconst flex_int32_t yy_meta[93] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    1,    3,    4,    1,
        5,    5,    5,    5,    1,    1,    1,    1,    1,    1,
        5,    5,    6,    1,    1,    1,    1,    5,    5,    5,
        5,    5,    5,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        7,    1,    1,    1,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6

    } ;

static yyconst flex_int16_t yy_base[409] =
    {   0,
        0,   91,  823,  824,  824,  824,  824,  824,  794,   87,
      824,  824,  793,   84,   85,  824,  824,   83,   85,  824,
       86,   84,  101,  104,  116,  795,  824,  103,   81,   90,
      824,    0,  824,  824,  791,  762,   49,   96,   82,   94,
      103,  769,  107,  778,  109,  126,  119,  122,  765,  763,
      768,  824,  123,  824,  824,   85,   79,  121,  171,  176,
      824,  824,  165,  824,  176,  824,  824,  824,  179,  824,
      180,  784,  824,  824,  824,  824,  824,  824,  824,  792,
      174,  186,  824,  782,  824,  198,  204,  210,  227,  234,
      239,  244,  824,  781,  824,  824,  824,  824,  824,  780,

        0,  824,  752,  755,  763,  158,  754,  760,    0,  748,
      745,  184,  752,  751,  745,  747,  745,    0,  743,  739,
      744,  744,  740,  751,  147,  199,  740,  219,  742,  734,
      213,  740,  733,  738,  737,  736,  824,  824,    0,    0,
        0,  753,  752,  700,  199,  706,  197,  214,  707,  688,
      204,  686,  236,  824,  267,  269,  824,  824,  272,  824,
      755,  276,  288,  292,  298,  268,  304,  284,  309,  326,
      351,  824,  824,  722,  724,  733,  728,  729,  279,  730,
      725,  717,  723,  722,  709,  720,  296,  721,  721,  708,
        0,  716,  697,  701,  707,  700,  707,  704,  694,  709,

      690,  271,  687,  698,  692,    0,  665,  675,  663,  672,
      664,  824,  824,    0,  683,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  682,  681,  674,  310,  682,  332,
      339,  318,  377,  385,  389,  355,  394,  402,  420,  444,
      395,  461,    0,    0,  653,    0,  653,  630,  635,  623,
        0,    0,  626,  627,  630,    0,  625,    0,  613,  629,
      613,  611,    0,  616,  611,  613,  590,    0,  575,  573,
      578,  573,  582,  581,  582,    0,  552,  565,  555,    0,
      562,  824,  824,  824,  824,  824,  341,  584,  467,  358,
      363,  407,  411,  581,  469,  424,  448,  473,  482,  494,

      580,  523,  489,  547,  570,  595,  540,    0,    0,    0,
      548,  549,  540,  542,    0,  537,  530,  512,  497,  497,
      508,  502,    0,  491,  490,  484,  487,  479,  467,  475,
      478,    0,  471,    0,    0,  398,  493,  517,  407,  491,
      552,  608,  535,  422,  489,  621,  638,  652,  665,  450,
      449,  456,    0,  447,  427,    0,    0,  435,  417,    0,
      410,    0,  384,    0,    0,    0,    0,    0,  379,  824,
      824,  285,  824,  415,    0,  357,    0,  355,  362,  355,
      340,  333,    0,  304,    0,  294,    0,  282,  223,    0,
      205,  172,    0,    0,    0,    0,  154,  149,    0,  824,

      715,  722,  725,  728,  733,  736,  741,  746
    } ;

static yyconst flex_int16_t yy_def[409] =
    {   0,
      400,    1,  400,  400,  400,  400,  400,  400,  400,  401,
      400,  400,  400,  400,  402,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  403,  400,  400,  400,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  400,  400,  400,  400,  403,  403,  403,  400,  400,
      400,  400,  401,  400,  401,  400,  400,  400,  402,  400,
      402,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,

      403,  400,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  400,  400,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  400,  400,  401,  402,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,

      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  400,  400,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      404,  405,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  406,  400,

      400,  400,  407,  400,  400,  400,  405,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  400,  400,  400,  400,  400,
      400,  400,  406,  400,  400,  400,  407,  400,  400,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  400,
      400,  408,  400,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,    0,

      400,  400,  400,  400,  400,  400,  400,  400
    } ;

static yyconst flex_int16_t yy_nxt[917] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
       24,   25,   25,   25,   26,   27,   28,   29,   30,   31,
       32,   32,   32,   33,    4,   34,   35,   36,   37,   38,
       39,   40,   41,   42,   32,   43,   32,   32,   32,   44,
       32,   45,   46,   47,   48,   49,   50,   51,   32,   32,
       52,   53,   54,   55,   32,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   56,
       57,   58,   59,   64,   67,   60,   70,   72,   61,  104,

       75,  105,   80,   77,   81,   81,   81,   81,   97,   98,
       73,   68,   76,   78,   79,   83,   74,   99,  100,   71,
       84,   65,   86,  108,   87,   87,   87,   88,   85,   94,
       95,   96,  109,  106,   86,   89,   88,   88,   88,   88,
      113,  110,   90,  111,   82,   89,  107,   89,  114,  118,
      137,  142,  112,  115,   91,  119,  120,   89,  116,  122,
      127,  123,   92,  125,  124,  143,  130,  126,  139,  140,
      141,   64,  153,  128,  131,  153,  129,  153,  154,  132,
      153,  133,  155,  154,  138,  144,  145,  146,  147,  148,
       70,  156,  196,  149,   81,   81,   81,   81,  399,   65,

      150,  197,  151,  152,  398,   89,  159,  159,  159,  159,
       65,  177,  178,   71,   71,   89,  161,  397,  162,  162,
      162,  162,   86,  183,   87,   87,   87,   88,   86,   89,
       88,   88,   88,   88,   82,   89,  198,  153,  184,   89,
      153,   89,  164,  154,  164,   89,  396,  165,  165,  165,
      165,   89,  166,  199,  167,  167,  201,  168,  163,  169,
      169,  169,  170,  395,  171,  171,  171,  171,  205,  215,
      216,  202,  206,   64,  171,  171,  218,  219,  225,  226,
       70,  171,  171,  171,  171,  171,  171,  220,  231,  231,
      221,  222,  159,  159,  159,  159,  162,  162,  162,  162,

      305,   65,  305,   71,  235,  235,  235,   89,  230,  230,
      230,  230,  165,  165,  165,  165,  272,   89,  165,  165,
      165,  165,  233,  394,  167,  167,  273,  237,  232,  169,
      169,  169,  248,  249,  228,  234,  163,  257,  287,  287,
      238,   89,  258,  393,  236,  234,  239,  239,  239,  239,
      238,   89,  230,  230,  230,  230,  239,  239,  392,  231,
      231,  287,  287,  239,  239,  239,  239,  239,  239,  241,
      234,  171,  171,  171,  171,  293,  293,  293,  338,  338,
      234,  171,  242,  292,  292,  391,  240,  390,  171,  171,
      171,  171,  242,  171,  228,  288,  389,  289,  289,  232,

      291,  388,  291,  336,  387,  292,  292,  386,  234,  235,
      235,  235,  294,  301,  295,  295,  295,  297,  234,  297,
      238,  383,  298,  298,  298,  238,  303,  292,  292,  234,
      238,  293,  293,  293,  382,  238,  303,  290,  238,  234,
      239,  239,  239,  239,  341,  341,  341,  381,  238,  236,
      239,  299,  384,  372,  296,  304,  385,  239,  239,  239,
      239,  299,  239,  372,  300,  300,  300,  300,  298,  298,
      298,  380,  379,  339,  300,  300,  305,  378,  305,  241,
      240,  300,  300,  300,  300,  300,  300,  289,  289,  295,
      295,  295,  307,  298,  298,  298,  377,  305,  234,  305,

      238,  376,  307,  375,  305,  374,  305,  373,  234,  371,
      238,  370,  369,  343,  300,  300,  300,  300,  368,  367,
      347,  366,  365,  343,  300,  300,  364,  290,  363,  296,
      347,  300,  300,  300,  300,  300,  300,  338,  338,  362,
      361,  360,  240,  302,  302,  302,  302,  359,  358,  304,
      305,  357,  305,  302,  303,  305,  344,  305,  241,  356,
      302,  302,  302,  302,  303,  302,  343,  348,  348,  348,
      348,  307,  341,  341,  341,  355,  343,  348,  348,  336,
      354,  307,  353,  304,  348,  348,  348,  348,  348,  348,
      349,  349,  349,  349,  352,  240,  351,  350,  345,  340,

      349,  349,  337,  335,  334,  333,  332,  349,  349,  349,
      349,  349,  349,  241,  339,  306,  306,  306,  306,  331,
      330,  329,  328,  327,  326,  306,  307,  325,  342,  342,
      342,  342,  306,  306,  306,  306,  307,  306,  342,  343,
      324,  346,  346,  346,  346,  342,  342,  342,  342,  343,
      342,  346,  347,  305,  323,  305,  322,  321,  346,  346,
      346,  346,  347,  346,  320,  319,  318,  317,  240,  347,
      316,  315,  348,  348,  348,  348,  314,  313,  312,  347,
      311,  304,  348,  348,  310,  349,  349,  349,  349,  348,
      348,  348,  348,  348,  348,  349,  349,  309,  304,  308,

      286,  285,  349,  349,  349,  349,  349,  349,  284,  283,
      282,  281,  280,  279,  344,   63,  278,   63,   63,   63,
       63,   63,   69,  277,   69,   69,   69,   69,   69,  101,
      101,  302,  302,  276,  302,  306,  306,  306,  342,  275,
      342,  274,  342,  346,  271,  346,  270,  346,  349,  269,
      349,  268,  267,  266,  265,  264,  263,  262,  261,  260,
      259,  256,  255,  254,  253,  252,  251,  250,  247,  246,
      245,  244,  243,  229,  227,  224,  223,  217,  214,  213,
      212,  211,  210,  209,  208,  207,  204,  203,  200,  195,
      194,  193,  192,  191,  190,  189,  188,  187,  186,  185,

      182,  181,  180,  179,  176,  175,  174,  173,  172,  160,
      158,  157,  136,  135,  134,  121,  117,  103,  102,   93,
       66,   62,  400,    3,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,

      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400
    } ;

static yyconst flex_int16_t yy_chk[917] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    2,   10,   14,    2,   15,   18,    2,   37,

       19,   37,   22,   21,   22,   22,   22,   22,   29,   29,
       18,   14,   19,   21,   21,   23,   18,   30,   30,   15,
       23,   10,   24,   39,   24,   24,   24,   24,   23,   28,
       28,   28,   39,   38,   25,   24,   25,   25,   25,   25,
       41,   40,   24,   40,   22,   24,   38,   25,   41,   43,
       53,   57,   40,   41,   24,   43,   43,   25,   41,   45,
       47,   45,   24,   46,   45,   57,   48,   46,   56,   56,
       56,   63,   59,   47,   48,   59,   47,   60,   59,   48,
       60,   48,   65,   60,   53,   58,   58,   58,   58,   58,
       69,   71,  125,   58,   81,   81,   81,   81,  398,   63,

       58,  125,   58,   58,  397,   81,   82,   82,   82,   82,
       65,  106,  106,   69,   71,   81,   86,  392,   86,   86,
       86,   86,   87,  112,   87,   87,   87,   87,   88,   86,
       88,   88,   88,   88,   81,   87,  126,  153,  112,   86,
      153,   88,   89,  153,   89,   87,  391,   89,   89,   89,
       89,   88,   90,  126,   90,   90,  128,   91,   86,   91,
       91,   91,   92,  389,   92,   92,   92,   92,  131,  145,
      145,  128,  131,  155,   92,   92,  147,  147,  151,  151,
      156,   92,   92,   92,   92,   92,   92,  148,  166,  166,
      148,  148,  159,  159,  159,  159,  162,  162,  162,  162,

      372,  155,  372,  156,  168,  168,  168,  162,  163,  163,
      163,  163,  164,  164,  164,  164,  202,  162,  165,  165,
      165,  165,  167,  388,  167,  167,  202,  169,  166,  169,
      169,  169,  179,  179,  159,  167,  162,  187,  232,  232,
      169,  228,  187,  386,  168,  167,  170,  170,  170,  170,
      169,  228,  230,  230,  230,  230,  170,  170,  384,  231,
      231,  287,  287,  170,  170,  170,  170,  170,  170,  171,
      231,  171,  171,  171,  171,  236,  236,  236,  290,  290,
      231,  171,  171,  291,  291,  382,  170,  381,  171,  171,
      171,  171,  171,  171,  230,  233,  380,  233,  233,  231,

      234,  379,  234,  287,  378,  234,  234,  376,  233,  235,
      235,  235,  237,  241,  237,  237,  237,  238,  233,  238,
      235,  369,  238,  238,  238,  237,  241,  292,  292,  336,
      235,  293,  293,  293,  363,  237,  241,  233,  339,  336,
      239,  239,  239,  239,  296,  296,  296,  361,  339,  235,
      239,  239,  374,  344,  237,  241,  374,  239,  239,  239,
      239,  239,  239,  344,  240,  240,  240,  240,  297,  297,
      297,  359,  358,  293,  240,  240,  242,  355,  242,  242,
      239,  240,  240,  240,  240,  240,  240,  289,  289,  295,
      295,  295,  242,  298,  298,  298,  354,  299,  289,  299,

      295,  352,  242,  351,  303,  350,  303,  345,  289,  340,
      295,  337,  333,  299,  300,  300,  300,  300,  331,  330,
      303,  329,  328,  299,  300,  300,  327,  289,  326,  295,
      303,  300,  300,  300,  300,  300,  300,  338,  338,  325,
      324,  322,  299,  302,  302,  302,  302,  321,  320,  303,
      343,  319,  343,  302,  302,  307,  300,  307,  307,  318,
      302,  302,  302,  302,  302,  302,  343,  304,  304,  304,
      304,  307,  341,  341,  341,  317,  343,  304,  304,  338,
      316,  307,  314,  302,  304,  304,  304,  304,  304,  304,
      305,  305,  305,  305,  313,  343,  312,  311,  301,  294,

      305,  305,  288,  281,  279,  278,  277,  305,  305,  305,
      305,  305,  305,  306,  341,  306,  306,  306,  306,  275,
      274,  273,  272,  271,  270,  306,  306,  269,  342,  342,
      342,  342,  306,  306,  306,  306,  306,  306,  342,  342,
      267,  346,  346,  346,  346,  342,  342,  342,  342,  342,
      342,  346,  346,  347,  266,  347,  265,  264,  346,  346,
      346,  346,  346,  346,  262,  261,  260,  259,  342,  347,
      257,  255,  348,  348,  348,  348,  254,  253,  250,  347,
      249,  346,  348,  348,  248,  349,  349,  349,  349,  348,
      348,  348,  348,  348,  348,  349,  349,  247,  347,  245,

      229,  227,  349,  349,  349,  349,  349,  349,  226,  225,
      215,  211,  210,  209,  348,  401,  208,  401,  401,  401,
      401,  401,  402,  207,  402,  402,  402,  402,  402,  403,
      403,  404,  404,  205,  404,  405,  405,  405,  406,  204,
      406,  203,  406,  407,  201,  407,  200,  407,  408,  199,
      408,  198,  197,  196,  195,  194,  193,  192,  190,  189,
      188,  186,  185,  184,  183,  182,  181,  180,  178,  177,
      176,  175,  174,  161,  152,  150,  149,  146,  144,  143,
      142,  136,  135,  134,  133,  132,  130,  129,  127,  124,
      123,  122,  121,  120,  119,  117,  116,  115,  114,  113,

      111,  110,  108,  107,  105,  104,  103,  100,   94,   84,
       80,   72,   51,   50,   49,   44,   42,   36,   35,   26,
       13,    9,    3,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,

      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "lex.l"
#line 2 "lex.l"
/* $Header: /local/src/CVS/nickle/lex.l,v 1.82 2005/01/14 05:44:00 keithp Exp $ */

/*
 * Copyright © 1988-2004 Keith Packard and Bart Massey.
 * All Rights Reserved.  See the file COPYING in this directory
 * for licensing information.
 */

#include	"nickle.h"
#include	"gram.h"
#include	"ref.h"
#include	<strings.h>
#include	<errno.h>
#ifdef HAVE_LIBREADLINE
#include	<readline/readline.h>
#include	<readline/history.h>
#endif
    
typedef struct _lexInput {
    DataType		data;
    struct _lexInput	*next;
    Value		file;
    Atom		name;
    int			lineno;
    Bool		at_bol;
    Bool		at_eof;
    Bool		interactive;
} LexInput;

LexInput    *lexInput;
extern int  ignorenl;
extern int  notCommand;
extern int  seeComment;
#define	    FILE_END_CHAR	-2
    
static void lexInputMark (void *object)
{
    LexInput *lex = object;
    
    MemReference (lex->next);
    MemReference (lex->file);
}

static DataType lexInputType = {
    lexInputMark, 0, "lexInputType"
};

void
NewLexInput (Value file, Atom name, Bool after, Bool interactive)
{
    ENTER ();
    LexInput	*lex;

    lex = MemAllocate (&lexInputType, sizeof (*lex));
    lex->file = file;
    lex->name = name;
    lex->lineno = 0;
    lex->at_bol = True;
    lex->at_eof = False;
    lex->interactive = interactive;
    if (after)
    {
	LexInput **prev;
	
	for (prev = &lexInput; *prev; prev = &(*prev)->next)
	    ;
	lex->next = 0;
	*prev = lex;
    } else {
	lex->next = lexInput;
	lexInput = lex;
    }
    EXIT ();
}

ReferencePtr	LexInputReference;

void
LexInit (void)
{
    ENTER ();

    LexInputReference = NewReference ((void **) &lexInput);
    MemAddRoot (LexInputReference);
    EXIT ();
}

Atom
LexFileName (void)
{
    if (lexInput)
	return lexInput->name;
    return AtomId ("<initialization>");
}

int
LexFileLine (void)
{
    if (lexInput)
	return lexInput->lineno;
    return 0;
}

Bool
LexInteractive (void)
{
    if (lexInput)
	return lexInput->interactive;
    return False;
}

Bool
LexResetInteractive (void)
{
    while (lexInput->next && !lexInput->interactive)
    {
	FileClose (lexInput->file);
	lexInput = lexInput->next;
    }
    if (lexInput->interactive)
	return True;
    return False;
}

Bool
LexFile (char *s, Bool complain, Bool after)
{
    Value	f;
    int		err;

    f = FileFopen (s, "r", &err);
    if (f == 0) {
	if (complain)
	    (void) FilePrintf (FileStderr, "%s: %s\n",
			       s, FileGetErrorMessage (err));
	return False;
    }
    (void) NewLexInput(f, AtomId (s), after, False);
    return True;
}

static int
LexGetChar (void)
{
    int	    c;

    for (;;)
    {
	c = FileInput (lexInput->file);
	if (c >= 0)
	    return c;
	if (c == FileBlocked)
	    ThreadsRun (0, lexInput->file);
	else
	{
	    if (!lexInput->next)
		return FileEOF;
	    lexInput->at_eof = True;
	    return '\n';
	}
    }
}

#ifdef HAVE_LIBREADLINE
static int
ReadlineGetChar (FILE *f)
{
    return LexGetChar ();
}
#endif

static Value
prompt (void)
{
    Value	v;
    
    if (ignorenl)
	v = lookupVar (0, "prompt2");
    else if (CurrentFrame)
	v = lookupVar (0, "prompt3");
    else
	v = lookupVar (0, "prompt");
    return v;
}

static int
LexGetInteractiveChar (void)
{
#ifdef HAVE_LIBREADLINE
    static char	*line, *line_base;
    int	    c;

    if (!line)
    {
	char    *p;
	Value	v;

	v = prompt ();
	p = StrzPart (prompt (), "invalid prompt");
	if (!p)
	    p = "??? ";
	for (;;)
	{
	    FileFlush (FileStdout, False);
	    FileFlush (FileStderr, False);
	    if (FileStdout->file.flags & FileOutputBlocked)
		ThreadsRun (0, FileStdout);
	    else if (FileStderr->file.flags & FileOutputBlocked)
		ThreadsRun (0, FileStderr);
	    else
		break;
	}
	rl_getc_function = ReadlineGetChar;
	rl_inhibit_completion = 1;
	line_base = readline (p);
	line = line_base;
	if (!line)
	    return FileEOF;
	add_history (line_base);
    }
    c = (*line++) & 0xff;
    if (!c)
    {
	c = '\n';
	free (line_base);
	line = 0;
    }
    return c;
#else
    if (lexInput->at_bol)
    {
	Value	v = prompt ();
	Print (FileStdout, v, 's', 0, 0, 0, ' ');
	FileFlush (FileStdout, True);
    }
    return LexGetChar ();
#endif
}

#undef YY_INPUT
#define YY_NO_UNPUT

static int yy_input (char *buf, int max_size)
{
    int	    c;
    int	    result = 0;
    
    while (result < max_size) {
	if (lexInput->at_eof)
	{
	    FileClose (lexInput->file);
	    lexInput = lexInput->next;
	}
	if (lexInput->interactive)
	    c = LexGetInteractiveChar ();
	else
	    c = LexGetChar ();
	if (lexInput->at_bol) { lexInput->lineno++; }
	lexInput->at_bol = False;
	if (c < 0) 
	    break;
	buf[result++] = c;
	if (c == '\n')
	{
	    lexInput->at_bol = True;
	    break;
	}
    }
    return result;
}

#define YY_INPUT(buf,result,max_size) ((result) = yy_input (buf, max_size))
    
#ifndef FLEX_SCANNER
#undef		input
#undef		unput
int input (void)
{
    char    buf[1];
    int	    r;

    YY_INPUT(buf, r, 1);
    if (r == 0)
	return 0;
    return buf[0];
}

void unput (char c)
{
    if (c == '\n')
	lexInput->lineno--;
    FileUnput (lexInput->file, c);
}
#endif

#line 1078 "lex.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 298 "lex.l"

#line 1234 "lex.c"

	if ( (yy_init) )
		{
		(yy_init) = 0;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 401 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 824 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 299 "lex.l"
{   
		    if (seeComment) 
		    {
			yylval.value = lexdoc ();
			return COMMENT_CONST;
		    }
		    else
			skipcomment (); 
		}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 308 "lex.l"
skipline();
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 309 "lex.l"
{ yylval.class = class_auto; return AUTO; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 310 "lex.l"
{ yylval.class = class_const; return CONST; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 311 "lex.l"
{ yylval.class = class_global; return GLOBAL; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 312 "lex.l"
{ yylval.class = class_static; return STATIC; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 313 "lex.l"
{ yylval.type = typePrim[rep_func]; return FUNCTION; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 314 "lex.l"
{ yylval.ints = WHILE; return WHILE; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 315 "lex.l"
{ yylval.ints = FOR; return FOR; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 316 "lex.l"
{ yylval.ints = DO; return DO; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 317 "lex.l"
{ yylval.ints = IF; return IF; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 318 "lex.l"
{ yylval.ints = ELSE; return ELSE; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 319 "lex.l"
{ yylval.ints = SWITCH; return SWITCH; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 320 "lex.l"
{ yylval.ints = BREAK; return BREAK; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 321 "lex.l"
{ yylval.ints = CONTINUE; return CONTINUE; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 322 "lex.l"
{ yylval.ints = CASE; return CASE; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 323 "lex.l"
{ yylval.ints = DEFAULT; return DEFAULT; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 324 "lex.l"
{ yylval.ints = RETURNTOK; return RETURNTOK; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 325 "lex.l"
{ yylval.ints = TRY; return TRY; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 326 "lex.l"
{ yylval.ints = CATCH; return CATCH; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 327 "lex.l"
{ yylval.ints = TWIXT; return TWIXT; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 329 "lex.l"
{ yylval.type = typePoly; return POLY; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 330 "lex.l"
{ yylval.type = typePrim[rep_bool]; return BOOL; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 331 "lex.l"
{ yylval.type = typePrim[rep_integer]; return INTEGER; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 332 "lex.l"
{ yylval.type = typePrim[rep_rational]; return RATIONAL; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 333 "lex.l"
{ yylval.type = typePrim[rep_float]; return REAL; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 334 "lex.l"
{ yylval.type = typePrim[rep_string]; return STRING; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 335 "lex.l"
{ yylval.type = typePrim[rep_file]; return FILET; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 336 "lex.l"
{ yylval.type = typePrim[rep_semaphore]; return SEMAPHORE; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 337 "lex.l"
{ yylval.type = typePrim[rep_continuation]; return CONTINUATION; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 338 "lex.l"
{ yylval.type = typePrim[rep_thread]; return THREAD; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 339 "lex.l"
{ yylval.ints = STRUCT; return STRUCT; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 340 "lex.l"
{ yylval.ints = UNION; return UNION; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 341 "lex.l"
{ yylval.ints = ENUM; return ENUM; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 342 "lex.l"
{ yylval.type = typePrim[rep_void]; return VOID; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 343 "lex.l"
{ yylval.type = typePrim[rep_foreign]; return FOREIGN; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 344 "lex.l"
{ yylval.value = TrueVal; return BOOLVAL; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 345 "lex.l"
{ yylval.value = FalseVal; return BOOLVAL; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 347 "lex.l"
{ yylval.ints = TYPEDEF; return TYPEDEF; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 348 "lex.l"
{ yylval.ints = FUNC; return FUNC; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 349 "lex.l"
{ yylval.ints = FORK; return FORK; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 350 "lex.l"
{ yylval.ints = NAMESPACE; return NAMESPACE; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 351 "lex.l"
{ yylval.ints = IMPORT; return IMPORT; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 352 "lex.l"
{ yylval.ints = EXCEPTION; return EXCEPTION; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 353 "lex.l"
{ yylval.ints = RAISE; return RAISE; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 354 "lex.l"
{ yylval.publish = publish_protected; return PROTECTED; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 355 "lex.l"
{ yylval.publish = publish_public; return PUBLIC; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 356 "lex.l"
{ yylval.publish = publish_extend; return EXTEND; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 357 "lex.l"
{ yylval.ints = SEMI; return SEMI; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 358 "lex.l"
{ yylval.ints = COMMA; return COMMA; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 359 "lex.l"
{ yylval.ints = DOLLAR; return DOLLAR; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 360 "lex.l"
{ yylval.ints = DOTDOTDOT; return DOTDOTDOT; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 361 "lex.l"
{ yylval.ints = DOTDOTDOT; return DOTDOTDOT; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 362 "lex.l"
{ yylval.ints = DOT; return DOT; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 363 "lex.l"
{ yylval.ints = ARROW; return ARROW; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 364 "lex.l"
{ yylval.ints = ARROW; return ARROW; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 365 "lex.l"
{ yylval.ints = DARROW; return DARROW; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 366 "lex.l"
{ yylval.ints = DARROW; return DARROW; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 367 "lex.l"
{ yylval.value = Void; return VOIDVAL; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 368 "lex.l"
{ yylval.value = Void; return VOIDVAL; }
	YY_BREAK
case 61:
/* rule 61 can match eol */
YY_RULE_SETUP
#line 369 "lex.l"
{ 
		    if (lexInput->at_eof) { strcpy (yytext, "EOF"); yylval.ints = ENDFILE; return ENDFILE; }
		    if (!ignorenl) { yylval.ints = NL; return NL; } 
		}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 373 "lex.l"
{ yylval.ints = OP; ++ignorenl; return OP; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 374 "lex.l"
{ yylval.ints = CP; if (ignorenl > 0) --ignorenl; return CP; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 375 "lex.l"
{ yylval.ints = STAROS; ++ignorenl; return STAROS; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 376 "lex.l"
{ yylval.ints = OS; ++ignorenl; return OS; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 377 "lex.l"
{ yylval.ints = CS; if (ignorenl > 0) --ignorenl; return CS; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 378 "lex.l"
{ yylval.ints = OC; ++ignorenl; return OC; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 379 "lex.l"
{ yylval.ints = CC; if (ignorenl > 0) --ignorenl; return CC; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 380 "lex.l"
{ yylval.ints = ASSIGNPLUS; return ASSIGNPLUS; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 381 "lex.l"
{ yylval.ints = ASSIGNMINUS; return ASSIGNMINUS; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 382 "lex.l"
{ yylval.ints = ASSIGNTIMES; return ASSIGNTIMES; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 383 "lex.l"
{ yylval.ints = ASSIGNTIMES; return ASSIGNTIMES; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 384 "lex.l"
{ yylval.ints = ASSIGNDIVIDE; return ASSIGNDIVIDE; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 385 "lex.l"
{ yylval.ints = ASSIGNDIVIDE; return ASSIGNDIVIDE; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 386 "lex.l"
{ yylval.ints = ASSIGNDIV; return ASSIGNDIV; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 387 "lex.l"
{ yylval.ints = ASSIGNDIV; return ASSIGNDIV; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 388 "lex.l"
{ yylval.ints = ASSIGNMOD; return ASSIGNMOD; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 389 "lex.l"
{ yylval.ints = ASSIGNPOW; return ASSIGNPOW; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 390 "lex.l"
{ yylval.ints = ASSIGNPOW; return ASSIGNPOW; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 391 "lex.l"
{ yylval.ints = ASSIGNSHIFTL; return ASSIGNSHIFTL; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 392 "lex.l"
{ yylval.ints = ASSIGNSHIFTL; return ASSIGNSHIFTL; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 393 "lex.l"
{ yylval.ints = ASSIGNSHIFTR; return ASSIGNSHIFTR; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 394 "lex.l"
{ yylval.ints = ASSIGNSHIFTR; return ASSIGNSHIFTR; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 395 "lex.l"
{ yylval.ints = ASSIGNLXOR; return ASSIGNLXOR; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 396 "lex.l"
{ yylval.ints = ASSIGNLAND; return ASSIGNLAND; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 397 "lex.l"
{ yylval.ints = ASSIGNLOR; return ASSIGNLOR; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 398 "lex.l"
{ yylval.ints = ASSIGN; return ASSIGN; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 400 "lex.l"
{ yylval.ints = PLUS; return PLUS; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 401 "lex.l"
{ yylval.ints = MINUS; return MINUS; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 402 "lex.l"
{ yylval.ints = TIMES; return TIMES; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 403 "lex.l"
{ yylval.ints = TIMES; return TIMES; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 404 "lex.l"
{ yylval.ints = DIVIDE; return DIVIDE; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 405 "lex.l"
{ yylval.ints = DIVIDE; return DIVIDE; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 406 "lex.l"
{ yylval.ints = DIV; return DIV; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 407 "lex.l"
{ yylval.ints = DIV; return DIV; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 408 "lex.l"
{ yylval.ints = STARSTAR; return STARSTAR; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 409 "lex.l"
{ yylval.ints = STARSTAR; return STARSTAR; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 410 "lex.l"
{ yylval.ints = MOD; return MOD; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 411 "lex.l"
{ yylval.ints = BANG; return BANG; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 412 "lex.l"
{ yylval.ints = POUND; return POUND; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 413 "lex.l"
{ yylval.ints = LAND; return LAND; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 414 "lex.l"
{ yylval.ints = LOR; return LOR; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 415 "lex.l"
{ yylval.ints = LXOR; return LXOR; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 416 "lex.l"
{ yylval.ints = LNOT; return LNOT; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 417 "lex.l"
{ yylval.ints = LNOT; return LNOT; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 418 "lex.l"
{ yylval.ints = INC; return INC; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 419 "lex.l"
{ yylval.ints = INC; return INC; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 420 "lex.l"
{ yylval.ints = DEC; return DEC; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 421 "lex.l"
{ yylval.ints = EQ; return EQ; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 422 "lex.l"
{ yylval.ints = NE; return NE; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 423 "lex.l"
{ yylval.ints = NE; return NE; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 424 "lex.l"
{ yylval.ints = LT; return LT; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 425 "lex.l"
{ yylval.ints = GT; return GT; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 426 "lex.l"
{ yylval.ints = LE; return LE; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 427 "lex.l"
{ yylval.ints = LE; return LE; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 428 "lex.l"
{ yylval.ints = GE; return GE; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 429 "lex.l"
{ yylval.ints = GE; return GE; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 430 "lex.l"
{ yylval.ints = AND; return AND; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 431 "lex.l"
{ yylval.ints = AND; return AND; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 432 "lex.l"
{ yylval.ints = OR; return OR; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 433 "lex.l"
{ yylval.ints = OR; return OR; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 434 "lex.l"
{ yylval.ints = SHIFTL; return SHIFTL; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 435 "lex.l"
{ yylval.ints = SHIFTL; return SHIFTL; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 436 "lex.l"
{ yylval.ints = SHIFTR; return SHIFTR; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 437 "lex.l"
{ yylval.ints = SHIFTR; return SHIFTR; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 438 "lex.l"
{ yylval.ints = QUEST; return QUEST; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 439 "lex.l"
{ yylval.ints = COLONCOLON; return COLONCOLON; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 440 "lex.l"
{ yylval.ints = COLON; return COLON; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 441 "lex.l"
{ yylval.ints = POW2; return POW2; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 442 "lex.l"
{ yylval.ints = POW3; return POW3; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 443 "lex.l"
;
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 444 "lex.l"
;
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 445 "lex.l"
;
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 446 "lex.l"
{
			ENTER ();
			char	 *s;
			long	len = yyleng - 1;
			int	c;
			s = yytext + 1;
			s = StringNextChar (s, &c, &len);
			if (c == '\\')
			{
			    if (!(s = StringNextChar (s, &c, &len)))
				c = 0;
			    else if ('0' <= c && c <= '7')
			    {
				int	ch;
				char    *ps = s;
				c = c - '0';
				while ((s = StringNextChar (s, &ch, &len)) &&
				       '0' <= ch && ch <= '7')
				{
				    c = (c << 3) | (ch - '0');
				    ps = s;
				}
				s = ps;
			    }
			    else
				c = lexEscape (c);
			}
			yylval.value = NewInt (c);
			EXIT ();
			REFERENCE (yylval.value);
			return CHAR_CONST;
		}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 478 "lex.l"
{
			ENTER ();
			char	*d, *s;
			int	c;
			long	len = yyleng - 2;

			yylval.value = NewString (len);
			d = StringChars (&yylval.value->string);
			s = yytext + 1;
			while ((s = StringNextChar (s, &c, &len)))
			{
			    if (c == '\\')
			    {
				if (!(s = StringNextChar (s, &c, &len)))
				    break;
				if ('0' <= c && c <= '7')
				{
				    int	    ch;
    				    char    *ps = s;
				    long    plen = len;
				    c = c - '0';
				    while ((s = StringNextChar (s, &ch, &len)) &&
					   '0' <= ch && ch <= '7')
				    {
					c = (c << 3) | (ch - '0');
					ps = s;
					plen = len;
				    }
				    s = ps;
				    len = plen;
				}
				else
				    c = lexEscape (c);
			    }
			    d += StringPutChar (c, d);
			}
			*d = '\0';
			yylval.value->string.length = d - StringChars(&yylval.value->string);
			EXIT ();
			REFERENCE (yylval.value);
			return STRING_CONST;
		}
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 520 "lex.l"
{
		yylval.value = atov(yytext+1, 8);
		if (yytext[1] == '\0')
		    return TEN_NUM;
	        else
		    return OCTAL0_NUM;
		}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 527 "lex.l"
{
		yylval.value = atov(yytext+2, 8);
		return OCTAL_NUM;
		}
	YY_BREAK
case 138:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 531 "lex.l"
{
		yylval.value = aetov(yytext+2, 8);
		return OCTAL_FLOAT;
		}
	YY_BREAK
case 139:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 535 "lex.l"
{
		yylval.value = atov(yytext+2, 8);
		return OCTAL_NUM;
		}
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 539 "lex.l"
{
		yylval.value = aetov (yytext+2, 8);
		return OCTAL_FLOAT;
		}
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 543 "lex.l"
{
		yylval.value = atov(yytext+2, 2);
		return BINARY_NUM;
		}
	YY_BREAK
case 142:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 547 "lex.l"
{
		yylval.value = aetov(yytext+2, 2);
		return BINARY_FLOAT;
		}
	YY_BREAK
case 143:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 551 "lex.l"
{
		yylval.value = atov(yytext+2, 2);
		return BINARY_NUM;
		}
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 555 "lex.l"
{
		yylval.value = aetov (yytext+2, 2);
		return BINARY_FLOAT;
		}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 559 "lex.l"
{
		yylval.value = atov(yytext+2, 16);
		return HEX_NUM;
		}
	YY_BREAK
case 146:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 563 "lex.l"
{
		yylval.value = aetov(yytext+2, 16);
		return HEX_FLOAT;
		}
	YY_BREAK
case 147:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 567 "lex.l"
{
		yylval.value = atov(yytext+2, 16);
		return HEX_NUM;
		}
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 571 "lex.l"
{
		yylval.value = aetov (yytext+2, 16);
		return HEX_FLOAT;
		}
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 575 "lex.l"
{
		yylval.value = atov(yytext, 10);
		return TEN_NUM;
		}
	YY_BREAK
case 150:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 579 "lex.l"
{
		yylval.value = aetov(yytext, 10);
		return TEN_FLOAT;
		}
	YY_BREAK
case 151:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 583 "lex.l"
{
		yylval.value = atov(yytext, 10);
		return TEN_NUM;
		}
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 587 "lex.l"
{
		yylval.value = aetov (yytext, 10);
		return TEN_FLOAT;
		}
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 591 "lex.l"
{
	        CommandPtr	c;
		SymbolPtr	symbol;
		yylval.atom = AtomId (yytext);
		if (!notCommand && (c = CommandFind (CurrentCommands, yylval.atom)))
		{
		    if (c->names)
			return NAMECOMMAND;
		    return COMMAND;
		}
		if (LexNamespace)
		    symbol = NamespaceFindName (LexNamespace, yylval.atom, False);
	        else
		    symbol = NamespaceFindName (CurrentNamespace, yylval.atom, True);
		if (symbol)
		{
		    switch (symbol->symbol.class) {
		    case class_namespace:
			return NAMESPACENAME;
		    case class_typedef:
			return TYPENAME;
		    default:
			break;
		    }
		}
		return NAME;
		}
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 618 "lex.l"
FilePrintf (FileStderr, "character \\%o ignored\n", *yytext & 0xff);
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 619 "lex.l"
ECHO;
	YY_BREAK
#line 2281 "lex.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 401 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 401 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 400);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yy_str )
{
    
	return yy_scan_bytes(yy_str,strlen(yy_str) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * bytes, int  len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < len; ++i )
		buf[i] = bytes[i];

	buf[len] = buf[len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
    	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
    	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#undef YY_NEW_FILE
#undef YY_FLUSH_BUFFER
#undef yy_set_bol
#undef yy_new_buffer
#undef yy_set_interactive
#undef yytext_ptr
#undef YY_DO_BEFORE_ACTION

#ifdef YY_DECL_IS_OURS
#undef YY_DECL_IS_OURS
#undef YY_DECL
#endif
#line 619 "lex.l"



int
lexEscape (int c)
{
    switch (c) {
    case '0':
	return '\0';
	break;
    case 'b':
	return '\b';
	break;
    case 'n':
	return '\n';
	break;
    case 'r':
	return '\r';
	break;
    case 't':
	return '\t';
	break;
    case 'f':
	return '\f';
	break;
    case 'v':
	return '\v';
	break;
    default:
	return c;
    }
}


Value
lexdoc (void)
{
    int	    c;
    Value   s = NewStrString ("");

    c = input();
    if (lexInput->at_eof)
    {
bail:	
        yyerror ("Missing */ at end of file");
        return Void;
    }
    for (;;) {
	Bool skip = False;
	while (c != EOF && c != '*')
	{
	    if (skip && c != ' ' && c != '\t')
		skip = False;
	    if (!skip)
		s = Plus (s, NewCharString (c));
	    if (c == '\n')
		skip = True;
	    c = input();
	    if (c == EOF || lexInput->at_eof)
		goto bail;
	}
	c = input();
	if (c == EOF || lexInput->at_eof)
	    goto bail;
	if (c == '/')
	    break;
	if (!skip)
	    s = Plus (s, NewCharString ('*'));
    }
    return s;
}

void
skipcomment (void)
{
    int	c;

    c = input();
    if (lexInput->at_eof)
    {
bail:	
        yyerror ("Missing */ at end of file");
        return;
    }
    for (;;) {
	while (c != EOF && c != '*')
	{
	    c = input();
	    if (c == EOF || lexInput->at_eof)
		goto bail;
	}
	c = input();
	if (c == EOF || lexInput->at_eof)
	    goto bail;
	if (c == '/')
	    return;
    }
}

void
skipline (void)
{
    int	    c;

    do {
	c = input();
    } while (c != EOF && c != '\n');
}

Value
atov (char *s, int base)
{
    ENTER ();
    Value	result;
    Value	b;
    char	c;
    int		i;

    b = NewInt (base);
    result = NewInt (0);
    for (;;) {
	c = *s++;
	if ('0' <= c  && c <= '9')
	    i = c - '0';
	else if ('a' <= c && c <= 'z')
	    i = c - 'a' + 10;
	else if ('A' <= c && c <= 'Z')
	    i = c - 'A' + 10;
	else
	    break;
	if (i >= base)
	    break;
	result = Plus (NewInt (i), Times (result, b));
    }
    RETURN (result);
}

Value
aetov (char *s, int base)
{
    ENTER ();
    char    *int_part, *frac_part, *rep_part, *exp_part, *next;
    int	    sign, frac_len, rep_len, esign;
    Value   v, sv;

    int_part = s;
    sign = 1;
    if (*int_part == '+')
	int_part++;
    else if (*int_part == '-') {
	int_part++;
	sign = -1;
    }
    next = int_part;
    frac_part = strchr (next, '.');
    frac_len = -1;
    rep_part = 0;
    rep_len = 0;
    esign = 1;
    if (frac_part) {
	frac_part++;
	next = frac_part;
	rep_part = strchr (next, '{');
	if (rep_part)
	{
	    frac_len = rep_part - frac_part;
	    rep_part++;
	    next = strchr (rep_part, '}');
	    if (!next)
		RETURN (Void);	    /* "can't" happen */
	    rep_len = next - rep_part;
	    next = next + 1;
	}
    }
    exp_part = strchr (next, 'e');
    if (!exp_part)
	exp_part = strchr (next, 'E');
    if (exp_part) {
	if (frac_len < 0)
	    frac_len = exp_part - frac_part;
	exp_part++;
	if (*exp_part == '+')
	    exp_part++;
	else if (*exp_part == '-') {
	    esign = -1;
	    exp_part++;
	}
    } else if (frac_len < 0 && frac_part)
	frac_len = strlen(frac_part);
    v = atov (int_part, base);
    if (frac_part)
    {
	v = Plus (v, Divide (atov (frac_part, base),
				 Pow (NewInt (base),
				       NewInt (frac_len))));
    }
    if (rep_part)
    {
	Value	rep;
	
	rep = Divide (atov (rep_part, base), Minus (Pow (NewInt (base),
						       NewInt (rep_len)),
						  One));
	if (frac_len)
	    rep = Divide (rep, Pow (NewInt (base),
				    NewInt (frac_len)));
	v = Plus (v, rep);
    }
    if (exp_part) 
    {
	sv = Pow (NewInt (base), atov (exp_part, base));
	if (esign > 0)
	    v = Times (v, sv);
	else
	    v = Divide (v, sv);
    }
    if (sign == -1)
	v = Negate (v);
    RETURN (v);
}


